#Different projection parameters
#North America +Central America
#proj.string.alb <- CRS("+proj=aea +lat_0=30 +lat_1=0 +lat_2=60 +lon_0=-90 +x_0=0 +y_0=0 +datum=WGS84 +units=km +no_defs")

#South America + Central America
#proj.string.alb <- CRS("+proj=aea +lat_0=-15 +lat_1=-60 +lat_2=30 +lon_0=-75 +x_0=0 +y_0=0 +datum=WGS84 +units=km +no_defs")

#Africa
#proj.string.alb <- CRS("+proj=aea +lat_0=0 +lat_1=-45 +lat_2=45 +lon_0=15 +x_0=0 +y_0=0 +datum=WGS84 +units=km +no_defs")

#Southeast Asia with India
#3proj.string.alb <- CRS("+proj=aea +lat_0=15 +lat_1=-15 +lat_2=30 +lon_0=100 +x_0=0 +y_0=0 +datum=WGS84 +units=km +no_defs")

#Europe
#proj.string.alb <- CRS("+proj=aea +lat_0=45 +lat_1=30 +lat_2=75 +lon_0=15 +x_0=0 +y_0=0 +datum=WGS84 +units=km +no_defs")

library(maptools)
library(PBSmapping)
library(rgdal)

#read in north american boundaries
n.america<-readShapeSpatial("bound_p")
debilis<-readShapeSpatial("species_54626")
boreas<-readShapeSpatial("species_3179")
alvarius<-readShapeSpatial("species_54567")

#Explicitly define the input projections using PROJ4 syntax
proj.string.latlon<-CRS("+proj=longlat +datum=WGS84")
proj4string(n.america)<-proj.string.latlon
proj4string(debilis)<-proj.string.latlon
proj4string(boreas)<-proj.string.latlon
proj4string(alvarius)<-proj.string.latlon

#reproject the input polygon data sets to Albers Equal Area with parameters set for North America
proj.string.alb <- CRS("+proj=aea +lat_1=30 +lat_2=60 +lat_0=45 +lon_0=-100 +x_0=0 +y_0=0 +datum=WGS84 +units=km +no_defs")
n.america.alb<-spTransform(n.america, CRS=proj.string.alb)
debilis.alb<-spTransform(debilis, CRS=proj.string.alb)
boreas.alb<-spTransform(boreas, CRS=proj.string.alb)
alvarius.alb<-spTransform(alvarius, CRS=proj.string.alb)

# Convert the spatial objects to PBSmapping objects (PolySet for
# polygons, EventData for points); for polygons, combinePolys is used to
# aggregate interior polygons into a single polygon

n.america.ps<- combinePolys(SpatialPolygons2PolySet(n.america.alb))
debilis.ps<- combinePolys(SpatialPolygons2PolySet(debilis.alb))
boreas.ps<- combinePolys(SpatialPolygons2PolySet(boreas.alb))
alvarius.ps<-combinePolys(SpatialPolygons2PolySet(alvarius.alb))

area.debilis<-sum(calcArea(debilis.ps, rollup=1)$area)
area.boreas<-sum(calcArea(boreas.ps,rollup=1)$area)
area.alvarius<-sum(calcArea(alvarius.ps,rollup=1)$area)

union<-combinePolys(joinPolys(debilis.ps,boreas.ps, "UNION", maxVert=1.0e+06))
area.union<-sum(calcArea(union,rollup=1)$area)
area.union
# [1] 4314200
area.debilis+area.boreas
# [1] 4498130
int<- combinePolys(joinPolys(debilis.ps, boreas.ps, "INT", maxVert = 1.0e+06))
#Error in combinePolys(joinPolys(debilis.ps, boreas.ps, "INT", maxVert = 1e+06)) : 
#  Invalid PolySet 'polys'.
#The object must be either a matrix or a data frame.
#debilis and boreas do not intersect that is what is causing the error, the sum of their areas is greater than the union is this diagnostic?

int<- combinePolys(joinPolys(debilis.ps, alvarius.ps, "INT", maxVert = 1.0e+06))
area.int<-sum(calcArea(int,rollup=1)$area)
area.int
#[1] 50606.1
area.debilis+area.alvarius
#[1] 1825435
union<-combinePolys(joinPolys(debilis.ps,alvarius.ps, "UNION", maxVert=1.0e+06))
area.union<-sum(calcArea(union,rollup=1)$area)
area.union
#[1] 1774829
# The intersection works but the sum of area is still greater than union so not diagnostic?

int<- combinePolys(joinPolys(boreas.ps, alvarius.ps, "INT", maxVert = 1.0e+06))
#Error in combinePolys(joinPolys(boreas.ps, alvarius.ps, "INT", maxVert = 1e+06)) : 
#  Invalid PolySet 'polys'.
#The object must be either a matrix or a data frame.

plotPolys(n.america.ps,xlim=c(-4000,3000),ylim=c(-3500,4000))

intersect<-function(x,y){
	int<- combinePolys(joinPolys(x, y, "INT", maxVert = 1.0e+06))
	area.int<-sum(calcArea(int,rollup=1)$area)
	return(area.int)
	}